# Shoulder

[![PyPI Latest Release](https://img.shields.io/pypi/v/shoulder.svg)](https://pypi.org/project/shoulder/)
[![License](https://img.shields.io/pypi/l/shoulder.svg)](https://github.com/gspangenberg/shoulder/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Shoulder is a patient specific anatomic coordinate system generator for shoulder bones. Currently it only generates coordinate systems for the humerus.

Install with
```
pip install shoulder
```
And then use the example code in tests/test_all.py

To contribute clone the repo and then install the dependencies from the poetry.lock file.

